@@ -6,7 +6,7 @@ use strict;
 use warnings;
 
 package Raisin::Entity;
-$Raisin::Entity::VERSION = '0.92';
+$Raisin::Entity::VERSION = '0.93';
 use parent 'Exporter';
 
 use Carp;
@@ -145,9 +145,7 @@ sub _make_exposition {
     my @columns = do {
         if (blessed($data)) {
             if ($data->isa('DBIx::Class::ResultSet')) {
-                my %columns = keys %{ $data->first->columns_info };
-                $data->reset;
-                %columns;
+                keys %{ $data->result_class->columns_info };
             }
             elsif ($data->isa('DBIx::Class::Core')) {
                 keys %{ $data->columns_info };
@@ -190,7 +188,7 @@ Raisin::Entity - A simple facade to use with your API
 
 =head1 VERSION
 
-version 0.92
+version 0.93
 
 =head1 SYNOPSIS
 
